package com.chinaitop.depot.business.controller;

import com.chinaitop.depot.business.model.BusinessNoticeReceive;
import com.chinaitop.depot.business.service.ReceiveNoticeService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 接收通知单
 * @author My   Sunshine
 *
 */
@RestController
@RequestMapping(value="/depot/business/receiveNotice")
@Api(description = "接收通知单")
public class ReceiveNoticeController {

	public static final Logger logger = LoggerFactory.getLogger(ReceiveNoticeController.class);
	
	@Resource
	private ReceiveNoticeService receiveNoticeService;


	/**
	 * 接收通知单列表
	 */
	@RequestMapping(value="/getList",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="通知单接收列表", notes = "查询数据列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "userId", value = "当前登录的用户编号", paramType = "query")
    })
    public PageInfo<BusinessNoticeReceive> getList(Integer pageNum, Integer pageSize , BusinessNoticeReceive businessNoticeReceive,String cktzd,String lyflag) throws Exception {

        List<BusinessNoticeReceive> list = receiveNoticeService.queryByExample(pageNum, pageSize, businessNoticeReceive,cktzd,lyflag);
        PageInfo<BusinessNoticeReceive> pageInfo = new PageInfo<BusinessNoticeReceive>(list);
        return pageInfo;
    }
   
	
	
	
	/**
	 * 根据id查询
	 */
	@RequestMapping(value="/edit", produces = MediaType.APPLICATION_JSON_VALUE,method=RequestMethod.GET)
    @ApiOperation(value="根据接收的通知单id查找信息", notes = "根据id查找")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "接收的通知单id", paramType = "query")
    })
    public BusinessNoticeReceive edit(Integer id) {
		BusinessNoticeReceive businessNoticeReceive = new BusinessNoticeReceive();
        if (id != null) {
        	businessNoticeReceive = receiveNoticeService.findById(id);
        }else{
        	businessNoticeReceive=new BusinessNoticeReceive();
        }

        return businessNoticeReceive;
    }
	
	
	
	/**
	 * 启用、暂停、终止
	 */
	@RequestMapping(value="/update", produces = MediaType.APPLICATION_JSON_VALUE,method=RequestMethod.POST)
    @ApiOperation(value="启用、暂停、终止", notes = "根据id修改状态(启用、暂停、终止)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "BusinessNoticeReceive", value = "接收到的通知单对象", paramType = "query")
    })
    public Map<String, Object> update(BusinessNoticeReceive businessNoticeReceive) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		if(businessNoticeReceive.getInApplication()!=null){
			receiveNoticeService.update(businessNoticeReceive);
			modelMap.put("status", "success");
		}else{
			modelMap.put("status", "error");
		}
        return modelMap;
    }
	
	/**
	 * 新增
	 */
	@RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="保存数据", notes = "保存")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "save", value = "新增数据", paramType = "query")
	})
    public Map<String, Object> save(String notice){

		logger.info("市平台传推送过来的轮换通知单是：\n"+notice);
		Map<String, Object> modelMap = new HashMap<String, Object>();
		try {
			modelMap = receiveNoticeService.add(notice);
		} catch (Exception e) {
			//e.printStackTrace();
			modelMap.put("status", "error");
			modelMap.put("msg", "保存失败！");
			logger.error(e.getMessage(), e);
		}
		return modelMap;
    }
    
}
