package com.chinaitop.depot.business.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.business.mapper.BusinessNoticeReceiveMapper;
import com.chinaitop.depot.business.model.BusinessNoticeReceive;
import com.chinaitop.depot.business.model.BusinessNoticeReceiveExample;
import com.chinaitop.depot.business.model.BusinessNoticeReceiveExample.Criteria;
import com.chinaitop.depot.business.service.FeignAgileService;
import com.chinaitop.depot.business.service.FeignBasicService;
import com.chinaitop.depot.business.service.ReceiveNoticeService;
import com.github.pagehelper.PageHelper;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class ReceiveNoticeServiceImpl implements ReceiveNoticeService {

	@Resource
    private BusinessNoticeReceiveMapper businessNoticeReceiveMapper;
	@Resource
	private FeignBasicService feignBasicService;
	@Resource
	private FeignAgileService feignAgileService;
	
	// 获取ip地址
    @Value("${crk-webservice}")
    private String url;
    
	@Override
	public List<BusinessNoticeReceive> queryByExample(Integer pageNum, Integer pageSize,
			BusinessNoticeReceive businessNoticeReceive,String cktzd,String lyflag) {
		// TODO Auto-generated method stub
		
		BusinessNoticeReceiveExample example = new BusinessNoticeReceiveExample();
        Criteria createCriteria = example.createCriteria();
        
        if(lyflag!=null){
        	if(lyflag.equals("0")){//油
        		createCriteria.andHouseIdIsNotNull();
        		createCriteria.andWareHouseIdIsNull();
        	}else if(lyflag.equals("1")){//粮
        		createCriteria.andHouseIdIsNotNull();
        		createCriteria.andWareHouseIdIsNotNull();
        	}
        }else{
        	//仓房
            if(businessNoticeReceive.getHouseId()!=null){
            	createCriteria.andHouseIdEqualTo(businessNoticeReceive.getHouseId());
            }
            //货位
            if(businessNoticeReceive.getWareHouseId()!=null){
            	createCriteria.andWareHouseIdEqualTo(businessNoticeReceive.getWareHouseId());
            }
        }
        
        //出入库类型
        if(businessNoticeReceive.getCrktype()!=null && businessNoticeReceive.getCrktype()!=""){
        	createCriteria.andCrktypeEqualTo(businessNoticeReceive.getCrktype());
        }
		//业务类型  竞买 销售 轮换
        if(cktzd!=null && cktzd.equals("0")){
        	if(businessNoticeReceive.getYwtype()!=null && businessNoticeReceive.getYwtype()!=""){
            	createCriteria.andYwtypeNotEqualTo(businessNoticeReceive.getYwtype());
            }
        }else{
        	if(businessNoticeReceive.getYwtype()!=null && businessNoticeReceive.getYwtype()!=""){
            	createCriteria.andYwtypeEqualTo(businessNoticeReceive.getYwtype());
            }
        }
        
        //组织id
        if(businessNoticeReceive.getOrgId()!=null){
        	createCriteria.andOrgIdEqualTo(businessNoticeReceive.getOrgId());
        }
        //通知单编号
        if(businessNoticeReceive.getNoticeNumber()!=null && businessNoticeReceive.getNoticeNumber()!=""){
        	createCriteria.andNoticeNumberEqualTo(businessNoticeReceive.getNoticeNumber());
        }
        //品种
        if(businessNoticeReceive.getGrainKind()!=null){
        	createCriteria.andGrainKindEqualTo(businessNoticeReceive.getGrainKind());
        }
        //性质
        if(businessNoticeReceive.getGrainAttribute()!=null){
        	createCriteria.andGrainAttributeEqualTo(businessNoticeReceive.getGrainAttribute());
        }
        //等级
        if(businessNoticeReceive.getGrainGrade()!=null){
        	createCriteria.andGrainGradeEqualTo(businessNoticeReceive.getGrainGrade());
        }
        if(pageNum!=null && pageSize!=null){
        	PageHelper.startPage(pageNum, pageSize);
        }
        example.setOrderByClause("receive_time desc");
        List<BusinessNoticeReceive> selectByExample = businessNoticeReceiveMapper.selectByExample(example);
        return selectByExample;
	}


	
	@Override
	public BusinessNoticeReceive findById(Integer id) {
		// TODO Auto-generated method stub
		return businessNoticeReceiveMapper.selectByPrimaryKey(id);
	}



	@Override
	public void update(BusinessNoticeReceive businessNoticeReceive) {
		// TODO Auto-generated method stub
		businessNoticeReceiveMapper.updateByPrimaryKeySelective(businessNoticeReceive);
	}



	@Override
	public Map<String, Object> add(String notice) throws Exception {

        Map<String, Object> modelMap = new HashMap<String, Object>();

        if(notice!=null){
            // JSON字符串转对象
            JSONObject jsonObject = JSONObject.parseObject(notice);
            BusinessNoticeReceive businessNoticeReceive = new BusinessNoticeReceive();
            businessNoticeReceive.setNoticeNumber(jsonObject.getString("tzdid")); //接收通知单编号

            if(jsonObject.getString("tzdlx")!=null && jsonObject.getString("ywlx")!=null){
                if(ObjectUtils.toString(jsonObject.getString("tzdlx")).equals("01")){ //出入库类型(01：出库 02:入库 03:出入库)
                    businessNoticeReceive.setCrktype("3"); //1入 3出
                    businessNoticeReceive.setForwardingUnit(jsonObject.getString("khssyqmc")); //发货单位
                }else if (ObjectUtils.toString(jsonObject.getString("tzdlx")).equals("02")){
                    businessNoticeReceive.setCrktype("1"); //1入 3出
                    businessNoticeReceive.setReceiveUnit(jsonObject.getString("ssyqmc")); //收货单位
                }else if(ObjectUtils.toString(jsonObject.getString("tzdlx")).equals("03")){
                    businessNoticeReceive.setCrktype("13"); //1入 3出
                    businessNoticeReceive.setForwardingUnit(jsonObject.getString("khssyqmc")); //发货单位
                }

                if(ObjectUtils.toString(jsonObject.getString("ywlx")).equals("6")){  //业务类型 (6:竞买；7：销售  4：轮换)
                    businessNoticeReceive.setYwtype("1"); //1收储 2 销售 3轮换
                }else if (ObjectUtils.toString(jsonObject.getString("ywlx")).equals("4")){
                    businessNoticeReceive.setYwtype("3");
                }else if (ObjectUtils.toString(jsonObject.getString("ywlx")).equals("7")){
                    businessNoticeReceive.setYwtype("2");
                }

                businessNoticeReceive.setContractNumber(jsonObject.getString("sshtbm")); //协议编号/合同编号

                String hwbm = jsonObject.getString("cfbm");
                if(hwbm!=null){
                    Integer grainAttribute = 0 ;
                    Integer grainKind = 0;
                    //根据仓房编码查询仓房、货位、组织机构数据
                    Map<String, Object> wareDataMap = feignBasicService.getWareDataByHwbm(hwbm);
                    if (null == wareDataMap) {
                        modelMap.put("msg", "未获取到对应仓房和货位信息");
                        modelMap.put("status", "error");
                    } else {
                        Integer houseId = (Integer) wareDataMap.get("houseId");
                        Integer wareHouseId = (Integer) wareDataMap.get("wareHouseId");
                        Integer orgId = (Integer) wareDataMap.get("orgId");
                        businessNoticeReceive.setHouseId(houseId); //仓房
                        businessNoticeReceive.setWareHouseId(wareHouseId); //货位
                        businessNoticeReceive.setOrgId(orgId);  //组织id
                        if(ObjectUtils.toString(jsonObject.getString("ywlx")).equals("6")){//竞买的业务类型
                            if(jsonObject.getString("pz")!=null){
                                String code = jsonObject.getString("pzbm");//品种编码
                                if (StringUtils.isNotBlank(code)) {
                                    code = code.substring(0,3);//获取前三位
                                    Map<String, Object> basicMap = feignBasicService.getIdByNameAndParentId(1061, null, code);//1004是生产年份的父ID
                                    businessNoticeReceive.setGrainKind((Integer) basicMap.get("enumId")); //接收的品种大类
                                }
                            }
                        }else{
                            //根据仓房、货位、orgId获取粮食品种等信息
                            Map<String, Object> map = feignAgileService.getDateByChHwh(orgId, houseId, wareHouseId);
                            grainAttribute = (Integer) map.get("hwxz"); //粮油性质
                            grainKind = (Integer) map.get("pz"); //品种
                            Integer grainDetailKind = (Integer) map.get("mxpz"); //明细品种
                            Integer grainGrade = (Integer) map.get("dj"); //等级
                            String inputTime = map.get("rq")+""; //入库时间
                            Date date = null;
                            if(inputTime!=null){
                                //String year=String.format("%tY", inputTime);

                                SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
                                date = sdf.parse(inputTime);
                                // 获取String字符串中的年
                                SimpleDateFormat y = new SimpleDateFormat("yyyy");
                                System.out.println(y.format(date));
                                String enumName = y.format(date);

                                Integer parentId = 1004;
                                Map<String, Object> basicMap = feignBasicService.getIdByNameAndParentId(parentId, enumName, null);//1004是生产年份的父ID
                                Integer productiveYear = (Integer) basicMap.get("enumId");
                                businessNoticeReceive.setProductiveYear(productiveYear);//生产年份
                                businessNoticeReceive.setGrainAnnual(productiveYear);//收获年度
                            }

                            Integer grainProducingArea = (Integer) map.get("gb"); //产地

                            businessNoticeReceive.setGrainKind(grainKind); //品种
                            businessNoticeReceive.setGrainDetailKind(grainDetailKind); //明细品种
                            businessNoticeReceive.setGrainGrade(grainGrade); //等级
                            businessNoticeReceive.setGrainAttribute(grainAttribute); //粮油性质
                            businessNoticeReceive.setInputTime(date);//入库时间
                            businessNoticeReceive.setGrainProducingArea(grainProducingArea);//产地

                        }
                        String  lsyqsl = jsonObject.getString("lsyqsl");
                        BigDecimal s = new BigDecimal(1000);
                        BigDecimal sumjhsl = new BigDecimal(lsyqsl);
                        BigDecimal sumCkslss = sumjhsl.multiply(s);
                        String count = sumCkslss.toString(); //吨转化为公斤

                        businessNoticeReceive.setCount(lsyqsl); //计划数量（吨）
                        businessNoticeReceive.setOutgoingPeriod(jsonObject.getString("ckqx")); //出库期限(日期格式)

                        businessNoticeReceive.setInApplication(1); //启用

                        businessNoticeReceive.setReceiveTime(new Date());//接收数据的时间
                        businessNoticeReceiveMapper.insert(businessNoticeReceive);
                    }


                   /**
                    * 修改粮食性质(轮换或者销售进行修改)
                    *   parameters[0] = ;     //单位ID
                        parameters[1] = ;     //粮食品种
                        parameters[2] = null; //空就行
                        parameters[3] = ;     //仓房ID
                        parameters[4] = ;     //货位ID
                        parameters[5] = ;     //需要改变成的粮食性质
                        parameters[6] = ;     //原来的粮食性质
                        parameters[7] = ;     //库存数量或者要改变的数量
                        parameters[8]=;      //批准文号(山西用)
                        parameters[9]=;      //性质变动原因
                        parameters[10] = ;  //1:新增；2：修改；3：删除
                    */
                   /*if(!ObjectUtils.toString(jsonObject.getString("ywlx")).equals("6")){
                       Object parameters[] = new Object[11];
                       parameters[0] = orgId+"";//组织id
                       parameters[1] = grainKind+"";//粮食品种
                       parameters[2] = null;//
                       parameters[3] = houseId+"";//仓房id
                       parameters[4] = wareHouseId+"";//货位id
                       parameters[5] = 6871+"";//需要改变成的粮食性质(其他商品粮)
                       parameters[6] = grainAttribute+"";//原来的粮食性质
                       parameters[7] = count+"";//原来的粮食性质
                       parameters[8] = jsonObject.getString("tzdid")+"";//原来的粮食性质
                       parameters[9] = "转储性质变动";
                       parameters[10] = 2+"";
                       String str = createKC.createKC("ChangeGrainAttribute", url, parameters);
                        if ("true".equals(str)) {
                            modelMap.put("status", "success");
                        } else {
                            modelMap.put("status", "error");
                            modelMap.put("msg", "保存失败，库存同步异常，请联系管理员！");
                            return modelMap;
                        }
                   }*/

                }else{
                    modelMap.put("msg", "仓房编码为空");
                    modelMap.put("status", "error");
                }

            }else{
                modelMap.put("msg", "通知单或者业务类型为空");
                modelMap.put("status", "error");
            }

        }else{
            modelMap.put("msg", "参数为空");
            modelMap.put("status", "error");
        }

		return modelMap;
	}

}
